"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _useSyntaxHighlighter = require("../../hooks/useSyntaxHighlighter");
var _styleTransformer = require("../../utils/style-transformer");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const monospaceFont = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
// Helper function to extract theme registration from Shiki theme input
function getThemeRegistration(theme) {
  if ('default' in theme) {
    return theme.default;
  }
  return theme;
}
const baseStyles = _reactNative.StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    paddingHorizontal: 16,
    paddingVertical: 8
  },
  token: {
    fontFamily: monospaceFont,
    fontSize: 14
  },
  container: {
    flex: 1
  }
});
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14
}) => {
  const stylesheet = (0, _react.useMemo)(() => {
    const themeRegistration = getThemeRegistration(theme);
    const styles = (0, _styleTransformer.getRNStylesFromShikiStyle)(themeRegistration);
    return _reactNative.StyleSheet.create({
      ...styles,
      editor: {
        backgroundColor: themeRegistration.colors?.['editor.background'] || '#1e1e1e'
      },
      token: {
        ...baseStyles.token,
        fontSize,
        color: themeRegistration.colors?.['editor.foreground'] || '#d4d4d4'
      }
    });
  }, [theme, fontSize]);
  const {
    tokens
  } = (0, _useSyntaxHighlighter.useSyntaxHighlighter)({
    text,
    language,
    languageId,
    theme
  });
  const renderToken = (token, index, lineIndex) => {
    const styles = [stylesheet.token];

    // Add token-specific styles from stylesheet based on scope
    const tokenScopes = Array.isArray(token.scope) ? token.scope : [token.scope];
    tokenScopes.forEach(scope => {
      if (stylesheet[scope]) {
        styles.push(stylesheet[scope]);
      }
    });

    // Add token-specific styles from the token itself
    const tokenStyles = {};
    if (token.color) {
      tokenStyles.color = token.color;
    }
    if (token.fontStyle === 'italic') {
      tokenStyles.fontStyle = 'italic';
    }
    if (token.fontWeight === 'bold') {
      tokenStyles.fontWeight = 'bold';
    }
    if (Object.keys(tokenStyles).length > 0) {
      styles.push(tokenStyles);
    }
    const finalStyle = _reactNative.StyleSheet.flatten(styles);
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: finalStyle,
      children: token.content.replace(/ /g, '\u00A0')
    }, `${lineIndex}-${index}`);
  };
  const renderLine = (line, lineIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: baseStyles.lineContainer,
    children: line.map((token, tokenIndex) => renderToken(token, tokenIndex, lineIndex))
  }, lineIndex);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    showsHorizontalScrollIndicator: _reactNative.Platform.OS !== 'web',
    style: [baseStyles.scrollView, stylesheet.editor],
    contentContainerStyle: baseStyles.container,
    children: tokens.map((line, index) => renderLine(line, index))
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map