"use strict";

function hexToRgb(hex) {
  // Remove # if present
  hex = hex.replace(/^#/, '');

  // Handle both 3 and 6 digit hex
  if (hex.length === 3) {
    hex = `${hex[0]}${hex[0]}${hex[1]}${hex[1]}${hex[2]}${hex[2]}`;
  }
  const result = /^([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
  return result ? {
    r: Number.parseInt(result[1], 16),
    g: Number.parseInt(result[2], 16),
    b: Number.parseInt(result[3], 16)
  } : null;
}
function normalizeColor(color) {
  if (!color) return 'transparent';

  // Handle hex colors
  if (color.startsWith('#')) {
    const rgb = hexToRgb(color);
    if (rgb) {
      return `rgb(${rgb.r}, ${rgb.g}, ${rgb.b})`;
    }
  }
  return color;
}
export function convertTokenColorsToReactStyle(tokenColors) {
  if (!tokenColors) return {};
  const styleMap = {};
  tokenColors.forEach(token => {
    if (!token.settings) return;

    // Handle global theme settings
    if (!token.scope) {
      styleMap.default = {
        color: normalizeColor(token.settings.foreground),
        backgroundColor: normalizeColor(token.settings.background)
      };
      return;
    }
    const scopes = Array.isArray(token.scope) ? token.scope : [token.scope];
    const style = {};
    if (token.settings.foreground) {
      style.color = normalizeColor(token.settings.foreground);
    }
    if (token.settings.background) {
      style.backgroundColor = normalizeColor(token.settings.background);
    }
    if (token.settings.fontStyle) {
      if (token.settings.fontStyle.includes('italic')) {
        style.fontStyle = 'italic';
      }
      if (token.settings.fontStyle.includes('bold')) {
        style.fontWeight = 'bold';
      }
    }
    scopes.forEach(scope => {
      styleMap[scope] = {
        ...(styleMap[scope] || {}),
        ...style
      };
    });
  });
  return styleMap;
}
export function getRNStylesFromShikiStyle(theme) {
  if (!theme) return {};
  try {
    const styles = {
      editor: {
        backgroundColor: normalizeColor(theme.colors?.['editor.background'])
      },
      base: {
        color: normalizeColor(theme.colors?.['editor.foreground'])
      }
    };

    // Process token colors
    if (theme.tokenColors) {
      const tokenStyles = convertTokenColorsToReactStyle(theme.tokenColors);
      Object.assign(styles, tokenStyles);
    }
    return styles;
  } catch {
    return {
      editor: {
        backgroundColor: '#1e1e1e'
      },
      base: {
        color: '#d4d4d4'
      }
    };
  }
}
//# sourceMappingURL=style-transformer.js.map