import type { ThemeRegistration } from '@shikijs/types'
import type { TextStyle } from 'react-native'

export function getRNStylesFromShikiStyle(theme: ThemeRegistration): Record<string, TextStyle> {
  if (!theme?.tokenColors)
    return {}

  const styles: Record<string, TextStyle> = {}

  // Convert tokenColors to RN styles
  theme.tokenColors.forEach((token) => {
    if (!token.settings || !token.scope)
      return

    const style: TextStyle = {}

    // Handle foreground color
    if (token.settings.foreground) {
      style.color = token.settings.foreground
    }

    // Handle fontStyle
    if (token.settings.fontStyle) {
      const fontStyles = token.settings.fontStyle.split(' ')
      style.fontStyle = fontStyles.includes('italic') ? 'italic' : 'normal'
      style.fontWeight = fontStyles.includes('bold') ? 'bold' : 'normal'
    }

    // Handle scopes
    const scopes = Array.isArray(token.scope) ? token.scope : [token.scope]
    scopes.forEach((scope) => {
      if (scope)
        styles[scope] = style
    })
  })

  // Add editor styles
  if (theme.colors) {
    styles.editor = {
      backgroundColor: theme.colors['editor.background'],
      color: theme.colors['editor.foreground'],
    }
  }

  return styles
}
